@@ -51,6 +51,10 @@ class SquadObject:
         if obj is None:
             obj = self
 
+        nested_endpoints = [x[1] for x in SquadApi.schema_nested_eps if x[0].lower() == obj.__class__.__name__.lower()]
+        if nested_endpoints:
+            setattr(obj, 'nested_endpoints', nested_endpoints)
+
         attrs = obj.attrs if len(obj.attrs) else [attr for attr in result.keys()]
         for attr in attrs:
             setattr(obj, attr.replace(' ', '_').replace('/', '_').replace('-', '_'), result[attr])
@@ -239,6 +243,15 @@ class Project(SquadObject):
         objects = self.builds(count=1, **filters)
         return first(objects)
 
+    def environments(self, count=DEFAULT_COUNT, **filters):
+        filters.update({'project': self.id})
+        return self.__fetch__(Environment, filters, count)
+
+    def environment(self, slug):
+        filters = {'slug': slug}
+        objects = self.environments(count=1, **filters)
+        return first(objects)
+
     def suites(self, count=DEFAULT_COUNT, **filters):
         filters.update({'project': self.id})
         return self.__fetch__(Suite, filters, count)
